%global with_mingw 0

%if 0%{?fedora}
%global with_mingw 1
%endif

Name:		nghttp2
Version:	1.64.0
Release:	3%{?dist}
Summary:	HTTP/2 C Library and tools
License:	MIT
URL:		https://nghttp2.org/
Packager:	Teddysun <i@teddysun.com>
Source0:	https://github.com/nghttp2/nghttp2/releases/download/v%{version}/nghttp2-%{version}.tar.xz
Source1:	https://github.com/nghttp2/nghttp2/releases/download/v%{version}/nghttp2-%{version}.tar.xz.asc
Source2:	tatsuhiro-t.pgp
Patch0:		0001-revert-migrate-to-ares_getaddrinfo.patch
Patch1:		0002-nghttp2-1.61.0-configure.patch
Patch2:		0003-nghttp2-1.62.0-Remove-ATOMIC_UINT32_INIT.patch

BuildRequires: CUnit-devel
BuildRequires: c-ares-devel
%if 0%{?rhel} <= 9
BuildRequires: gcc-toolset-14
%else
BuildRequires: gcc-c++
%endif
BuildRequires: libev-devel
BuildRequires: libxml2-devel
BuildRequires: make
BuildRequires: openssl-devel
BuildRequires: python3-devel
BuildRequires: systemd-rpm-macros
BuildRequires: zlib-devel

# For gpg verification of source tarball
BuildRequires: gnupg2

Requires: libnghttp2%{?_isa} = %{version}-%{release}
%{?systemd_requires}

%if %{with_mingw}
BuildRequires: mingw32-filesystem >= 107
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw32-binutils
BuildRequires: mingw32-c-ares
BuildRequires: mingw32-libxml2
BuildRequires: mingw32-openssl
BuildRequires: mingw32-python3
BuildRequires: mingw32-zlib

BuildRequires: mingw64-filesystem >= 107
BuildRequires: mingw64-gcc-c++
BuildRequires: mingw64-binutils
BuildRequires: mingw64-c-ares
BuildRequires: mingw64-libxml2
BuildRequires: mingw64-openssl
BuildRequires: mingw64-python3
BuildRequires: mingw64-zlib
%endif

%description
This package contains the HTTP/2 client, server and proxy programs.


%package -n libnghttp2
Summary: A library implementing the HTTP/2 protocol

%description -n libnghttp2
libnghttp2 is a library implementing the Hypertext Transfer Protocol
version 2 (HTTP/2) protocol in C.


%package -n libnghttp2-devel
Summary: Files needed for building applications with libnghttp2
Requires: libnghttp2%{?_isa} = %{version}-%{release}
Requires: pkgconfig

%description -n libnghttp2-devel
The libnghttp2-devel package includes libraries and header files needed
for building applications with libnghttp2.

%if %{with_mingw}
%package -n mingw32-libnghttp2
Summary: A library implementing the HTTP/2 protocol

%description -n mingw32-libnghttp2
libnghttp2 is a library implementing the Hypertext Transfer Protocol
version 2 (HTTP/2) protocol in C.

This is the MinGW cross-compiled Windows library.

%package -n mingw64-libnghttp2
Summary: A library implementing the HTTP/2 protocol

%description -n mingw64-libnghttp2
libnghttp2 is a library implementing the Hypertext Transfer Protocol
version 2 (HTTP/2) protocol in C.

This is the MinGW cross-compiled Windows library.

%{?mingw_debug_package}
%endif

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%setup -q
%if 0%{?el8}
%patch0 -p1
%patch1 -p1
%endif
%patch2 -p1
autoreconf -fiv

%build
%if 0%{?rhel} <= 9
. /opt/rh/gcc-toolset-14/enable
%endif
mkdir build
pushd build
%define _configure ../configure
%configure PYTHON=%{__python3}              \
    --disable-hpack-tools                   \
    --disable-python-bindings               \
    --disable-static                        \
    --with-libxml2

# avoid using rpath
sed -i libtool                              \
    -e 's/^runpath_var=.*/runpath_var=/'    \
    -e 's/^hardcode_libdir_flag_spec=".*"$/hardcode_libdir_flag_spec=""/'

%make_build
popd

%if %{with_mingw}
%mingw_configure --disable-hpack-tools --disable-static
%mingw_make_build
%endif


%install
pushd build
%make_install
install -D -m0444 -p contrib/nghttpx.service "%{buildroot}%{_unitdir}/nghttpx.service"
popd

# not needed on Fedora/RHEL
rm -f "%{buildroot}%{_libdir}/libnghttp2.la"

# will be installed via %%doc
rm -f "%{buildroot}%{_datadir}/doc/nghttp2/README.rst"

%ldconfig_scriptlets -n libnghttp2

%if %{with_mingw}
%mingw_make_install
%mingw_debug_install_post

rm -f "${buildroot}%{mingw32_libdir}/libnghttp2.la"
rm -f "${buildroot}%{mingw64_libdir}/libnghttp2.la"
rm -f "%{buildroot}%{mingw32_datadir}/doc/nghttp2/README.rst"
rm -f "%{buildroot}%{mingw64_datadir}/doc/nghttp2/README.rst"
rm -r "%{buildroot}%{mingw32_mandir}/man1"
rm -r "%{buildroot}%{mingw64_mandir}/man1"
%endif


%check
# test the just built library instead of the system one, without using rpath
export "LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH"
pushd build
%if 0%{?rhel} <= 9
. /opt/rh/gcc-toolset-14/enable
%endif
%make_build check
popd


%post
%systemd_post nghttpx.service

%postun
%systemd_postun nghttpx.service


%files
%{_bindir}/h2load
%{_bindir}/nghttp
%{_bindir}/nghttpd
%{_bindir}/nghttpx
%{_datadir}/nghttp2
%{_mandir}/man1/h2load.1*
%{_mandir}/man1/nghttp.1*
%{_mandir}/man1/nghttpd.1*
%{_mandir}/man1/nghttpx.1*
%{_unitdir}/nghttpx.service

%files -n libnghttp2
%{_libdir}/libnghttp2.so.*
%{!?_licensedir:%global license %%doc}
%license COPYING

%files -n libnghttp2-devel
%{_includedir}/nghttp2
%{_libdir}/pkgconfig/libnghttp2.pc
%{_libdir}/libnghttp2.so
%doc README.rst

%if %{with_mingw}
%files -n mingw32-libnghttp2
%license COPYING
%doc README.rst
%{mingw32_bindir}/libnghttp2-14.dll
%{mingw32_libdir}/libnghttp2.dll.a
%{mingw32_libdir}/pkgconfig/libnghttp2.pc
%{mingw32_includedir}/nghttp2/
%{mingw32_datadir}/nghttp2/

%files -n mingw64-libnghttp2
%license COPYING
%doc README.rst
%{mingw64_bindir}/libnghttp2-14.dll
%{mingw64_libdir}/libnghttp2.dll.a
%{mingw64_libdir}/pkgconfig/libnghttp2.pc
%{mingw64_includedir}/nghttp2/
%{mingw64_datadir}/nghttp2/
%endif

%changelog
* Fri Jan 24 2025 Teddysun <i@teddysun.com> - 1.64.0-3
- Fix FTBFS - munit: Remove-ATOMIC_UINT32_INIT

* Sun Dec 29 2024 Teddysun <i@teddysun.com> - 1.64.0-2
- Built with GCC 14 on EL8 and EL9

* Mon Oct 21 2024 Teddysun <i@teddysun.com> - 1.64.0-1
- Update version to 1.64.0

* Tue Aug 27 2024 Teddysun <i@teddysun.com> - 1.63.0-1
- Update version to 1.63.0

* Sat May 25 2024 Teddysun <i@teddysun.com> - 1.62.1-1
- Update version to 1.62.1
- nghttp2 requires C++20 and is built with GCC 13 on EL8 and EL9

* Tue May 14 2024 Jan Macku <jamacku@redhat.com> 1.62.0-1
- update to the latest upstream release

* Thu Apr 04 2024 Jan Macku <jamacku@redhat.com> 1.61.0-1
- update to the latest upstream release
- fixes CVE-2024-28182 - HTTP/2 CONTINUATION frames can be utilized for DoS attacks
